==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/36/362254c9ae50b64d2f29cf53fdc6d375.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png */
class __TwigTemplate_1ab63ccedd0aff2d70aa428448352e2b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000\000\000\000IDATxc``\000\000\000\000h&Y
\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png", "/var/www/mautic-ktn/themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/36/362254c9ae50b64d2f29cf53fdc6d375.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png */
class __TwigTemplate_1ab63ccedd0aff2d70aa428448352e2b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000\000\000\000IDATxc``\000\000\000\000h&Y
\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/assets/newsletter.png");
    }
}
